@@ -79,6 +79,12 @@ class Encoder:
         r = Encoder.interface.send_request(
             rtype=RequestTypes.POST, route="encoder", json=body
         )
+        
+        while r["statusCode"] == 202:
+            encoderId = r["data"]["encoderId"]
+            r = Encoder.interface.send_request(
+                rtype=RequestTypes.GET, route="encoder", path_parameters=encoderId
+            )
         return Encoder.Item(r)
 
     @staticmethod
