@@ -16,7 +16,7 @@ def remove_empty(data):
 
     final_dict = {}
     for key, val in data.items():
-        if val or isinstance(val, int): # val = int(0) shoud not be removed 
+        if val or isinstance(val, int):  # val = int(0) shoud not be removed
             if isinstance(val, dict):
                 final_dict[key] = remove_empty(val)
             elif isinstance(val, list):
@@ -34,19 +34,24 @@ class RequestInterface:
         self.family = family
 
     def make_header(self):
-        return {
+        header = {
             "x-api-key": audiostack.api_key,
             "x-python-sdk-version": audiostack.sdk_version
-            # "x-assume-org": audiostack.assume_org_id,
         }
+        if audiostack.assume_org_id:
+            header["x-assume-org"] = audiostack.assume_org_id
+        return header
+
 
     def resolve_response(self, r):
+        if self.DEBUG_PRINT:
+            print(json.dumps(r.json(), indent=4))
         if r.status_code >= 500:
-            print(r)
             raise Exception("Internal server error - aborting")
-        
+
         if r.status_code == 403:
-            raise Exception("Not authorised - check API key is valid")
+            exc = r.json().get("message", "Not authorised - check API key is valid")
+            raise Exception(exc)
 
         if r.status_code >= 400:
             msg = (
@@ -63,10 +68,8 @@ class RequestInterface:
         #         "bytes" : r.content,
         #         "statusCode" : r.status_code
         #     }
-            
+
         # else:
-        if self.DEBUG_PRINT:
-            print(json.dumps(r.json(), indent=4))
         if "meta" in r.json():
             if "creditsUsed" in r.json()["meta"]:
                 audiostack.billing_session += r.json()["meta"]["creditsUsed"]
